@@ -15,7 +15,7 @@ A class to model a social link on a link site (part of App::LinkSite).
 use Feature::Compat::Class;
 
 class App::LinkSite::Social {
-  our $VERSION = '0.0.11';
+  our $VERSION = '0.0.13';
   use strict;
   use warnings;
   use feature qw[say signatures];
@@ -148,7 +148,7 @@ The name of the social media site's icon as represented in Font Awesome
 =cut
 
   method social_icon_template {
-    return q[<a title='%s' href='%s'><i class='fa-brands fa-3x fa-%s'></i></a>];
+    return q[<a rel='me' title='%s' href='%s'><i class='fa-brands fa-3x fa-%s'></i></a>];
   }
 
 =head2 mk_social_icon
